@@ -1,7 +1,7 @@
 import time
 
 
-class DeviceCredentialMixin(object):
+class DeviceCredentialMixin:
     def get_client_id(self):
         raise NotImplementedError()
 
@@ -17,22 +17,22 @@ class DeviceCredentialMixin(object):
 
 class DeviceCredentialDict(dict, DeviceCredentialMixin):
     def get_client_id(self):
-        return self['client_id']
+        return self["client_id"]
 
     def get_scope(self):
-        return self.get('scope')
+        return self.get("scope")
 
     def get_user_code(self):
-        return self['user_code']
+        return self["user_code"]
 
     def get_nonce(self):
-        return self.get('nonce')
+        return self.get("nonce")
 
     def get_auth_time(self):
-        return self.get('auth_time')
+        return self.get("auth_time")
 
     def is_expired(self):
-        expires_at = self.get('expires_at')
+        expires_at = self.get("expires_at")
         if expires_at:
             return expires_at < time.time()
         return False
